#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-parallel
version:              0.8.0.1
visibility:           public
id:                   monad-parallel-0.8.0.1-AmihbDeFbBpDguK5VC6yTf
key:                  monad-parallel-0.8.0.1-AmihbDeFbBpDguK5VC6yTf
license:              BSD-3-Clause
copyright:            (c) 2010-2022 Mario Blazevic
maintainer:           blamario@yahoo.com
author:               Mario Blazevic
homepage:             https://hub.darcs.net/blamario/SCC.wiki/
synopsis:             Parallel execution of monadic computations
description:
    This package defines classes of monads that can perform multiple executions in parallel and combine their results. For
    any monad that'\''s an instance of the class, the package re-implements a subset of the Control.Monad interface, but with
    parallel execution.

category:             Control, Monads
abi:                  af8e2144c6cca98e4ceda0bba5e976fd
exposed:              True
exposed-modules:      Control.Monad.Parallel
import-dirs:          /usr/lib/ghc-9.6.6/site-local/monad-parallel-0.8.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/monad-parallel-0.8.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/monad-parallel-0.8.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-parallel
hs-libraries:         HSmonad-parallel-0.8.0.1-AmihbDeFbBpDguK5VC6yTf
depends:
    base-4.18.2.1 parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH

haddock-interfaces:
    /usr/share/doc/haskell-monad-parallel/html/monad-parallel.haddock

haddock-html:         /usr/share/doc/haskell-monad-parallel/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

